@@ -1,11 +1,6 @@
-try:
-    import logging
-    import sys
-    import datetime
-    import os
-except Exception as err:
-    from core.exception import AwdExceptions
-    raise AwdExceptions(str(err))
+import logging
+import sys
+import datetime
 
 
 def setLog():
