@@ -1,11 +1,6 @@
 # -*- coding:utf-8 -*-
-try:
-    import cx_Oracle
-    import pandas as pd
-except Exception as err:
-    from core.exception import AwdExceptions
-
-    raise AwdExceptions(str(err))
+import cx_Oracle
+import pandas as pd
 
 
 class ORACLE(object):
