@@ -3,7 +3,6 @@ from __future__ import print_function
 import sys
 import os
 import cmd
-import argparse
 from threading import Thread
 
 try:
@@ -11,15 +10,8 @@ try:
 except ImportError:
     import configparser as ConfigParser
 
-try:
-    from impacket.examples import logger
-    from impacket import version, smbserver
-    from impacket.dcerpc.v5 import transport, scmr
-    from impacket.krb5.keytab import Keytab
-except Exception as err:
-    from core.exception import AwdExceptions
-
-    raise AwdExceptions(str(err))
+from impacket import smbserver
+from impacket.dcerpc.v5 import transport, scmr
 
 OUTPUT_FILENAME = '__output'
 BATCH_FILENAME = 'execute.bat'
@@ -214,7 +206,7 @@ class RemoteShell(cmd.Cmd):
     def do_cd(self, s):
         # We just can't CD or maintain track of the target dir.
         if len(s) > 0:
-            raise AwdExceptions("You can't Cd under smbExec. Use Full paths.")
+            raise ConnectionError("You can't Cd under smbExec. Use Full paths.")
 
         self.execute_remote('cd ')
         if len(self.__outputBuffer) > 0:
