@@ -1,9 +1,4 @@
-try:
-    import pymssql
-    from core.exception import AwdExceptions
-except Exception as err:
-    from core.exception import AwdExceptions
-    raise AwdExceptions(str(err))
+import pymssql
 
 class MSSQL:
     def __init__(self,host,username,password,db):
@@ -14,11 +9,11 @@ class MSSQL:
 
     def __GetConnect(self):
         if not self.db:
-            raise AwdExceptions("请设置数据库信息 !")
+            raise ConnectionError("请设置数据库信息")
         self.conn = pymssql.connect(host=self.host,user=self.user,password=self.pwd,database=self.db,charset="utf8")
         cur = self.conn.cursor()
         if not cur:
-            raise AwdExceptions("连接数据库失败 !")
+            raise ConnectionError("连接数据库失败")
         else:
             return cur
 
