@@ -1,21 +1,13 @@
 #!/usr/bin/python
 # coding:utf-8
 
-try:
-    import os
-    import stat
-    import paramiko
-    import traceback
-    from core.exception import AwdExceptions
-except Exception as err:
-    from core.exception import AwdExceptions
-
-    raise AwdExceptions(str(err))
+import os
+import stat
+import paramiko
 
 
-class SSH(object):
-
-    def __init__(self, host, port=22, username="root", password=None, keyPath="/root/.ssh/id_rsa", timeout=30):
+class SSH:
+    def __init__(self, host, port=22, username="root", password=None, keyPath=None, timeout=30):
         self.ip = host
         self.port = port
         self.username = username
@@ -37,10 +29,10 @@ class SSH(object):
         self.ssh.connect(hostname=self.ip, port=self.port, username=self.username, pkey=self.pkey)
         self.t.connect(username=self.username, pkey=self.pkey)
 
-    def connect(self):
-        try:
+    def connect(self, keyPath):
+        if keyPath:
             self._key_connect()
-        except Exception as e:
+        else:
             self._password_connect()
 
     def close(self):
@@ -50,8 +42,13 @@ class SSH(object):
     def execute_cmd(self, cmd):
         stdin, stdout, stderr = self.ssh.exec_command(cmd)
         res, error = stdout.read(), stderr.read()
-        result = res if res else error
-        return result.decode()
+        if res:
+            result = res
+            return result.decode()
+        else:
+            raise RuntimeError(error)
+        # result = res if res else error
+        # return result.decode()
 
     # 从远程服务器获取文件到本地
     def _sftp_get(self, remoteFile, localFile):
@@ -124,17 +121,17 @@ class SSH(object):
         sftp.stat(dst_path)
 
 
-def SSHExec(host, port, username, password, command, dst_path=None, keyPath="/root/.ssh/id_rsa"):
+def SSHExec(host, port, username, password, command, dst_path=None, keyPath=None):
     conn = SSH(host=host, port=port, username=username, password=password, keyPath=keyPath, timeout=30)
-    conn.connect()
+    conn.connect(keyPath)
     if dst_path:
         return conn.checkFile(dst_path)
     return conn.execute_cmd(command)
 
 
-def SSHUpload(host, port, username, password, src_path, dst_path, keyPath="/root/.ssh/id_rsa"):
+def SSHUpload(host, port, username, password, src_path, dst_path, keyPath):
     conn = SSH(host=host, port=port, username=username, password=password, keyPath=keyPath, timeout=30)
-    conn.connect()
+    conn.connect(keyPath)
     if os.path.isdir(src_path):
         conn.sftp_put_dir(src_path, dst_path)
     else:
