@@ -1,12 +1,7 @@
 #!/usr/bin/python
 # coding:utf-8
-try:
-    import pyminizip
-    import os
-except Exception as err:
-    from core.exception import AwdExceptions
-
-    raise AwdExceptions(str(err))
+import pyminizip
+import os
 
 
 def deleteFile(path):
@@ -84,7 +79,7 @@ class ZipObj:
         #     p = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         #     p.wait()
 
-        pyminizip.compress(self.src_path, '', self.dst_path, passwd, level=5)
+        pyminizip.compress(self.src_path, '', self.dst_path, passwd, 5)
 
         if os.path.exists(self.dst_path):
             if deleteSource:
@@ -104,7 +99,6 @@ class ZipObj:
 def zipEnc(src_path, dst_path='', passwd='', deleteSource=False):
     if len(dst_path) == 0:
         dst_path = src_path + '.zip'
-
     createZipFile = ZipObj(src_path, dst_path)
     createOk = createZipFile.enCrypt(passwd, deleteSource)
     if createOk:
